Module agent_store

Module agent_store 

Trait and types for persistent agent management.

The trait lives in agentzero-core so that agentzero-infra (the tool host) can depend on it without creating a circular dependency with agentzero-orchestrator (where the concrete AgentStore lives).

Structs

AgentChannelConfig
Channel configuration for a dynamic agent.
AgentRecord
Persistent record for a dynamically-created agent.
AgentUpdate
Fields that can be updated on an existing agent.

Enums

AgentStatus
Status of a dynamically-created agent.

Traits

AgentStoreApi
Trait for persistent agent CRUD operations.