Trait and types for persistent agent management.
The trait lives in agentzero-core so that agentzero-infra (the tool
host) can depend on it without creating a circular dependency with
agentzero-orchestrator (where the concrete AgentStore lives).
Structs
- Agent
Channel Config - Channel configuration for a dynamic agent.
- Agent
Record - Persistent record for a dynamically-created agent.
- Agent
Update - Fields that can be updated on an existing agent.
Enums
- Agent
Status - Status of a dynamically-created agent.
Traits
- Agent
Store Api - Trait for persistent agent CRUD operations.